/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*  Fluent Bit
 *  ==========
 *  Copyright (C) 2019      The Fluent Bit Authors
 *  Copyright (C) 2015-2018 Treasure Data Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

#include <fluent-bit/flb_info.h>
#include <fluent-bit/flb_regex.h>

#include "kube_conf.h"
#include "kube_regex.h"

int flb_kube_regex_init(struct flb_kube *ctx)
{
    /* If a custom parser is not set, use the defaults */
    if (!ctx->parser) {
        if (ctx->use_journal == FLB_TRUE) {
            ctx->regex = flb_regex_create(KUBE_JOURNAL_TO_REGEX);
        }
        else {
            ctx->regex = flb_regex_create(KUBE_TAG_TO_REGEX);
        }
    }

    if (!ctx->regex) {
        return -1;
    }

    return 0;
}
